# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _obexftp
else:
    import _obexftp

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


IRDA = _obexftp.IRDA
INET = _obexftp.INET
CABLE = _obexftp.CABLE
BLUETOOTH = _obexftp.BLUETOOTH
USB = _obexftp.USB
SYNC = _obexftp.SYNC
PUSH = _obexftp.PUSH
FTP = _obexftp.FTP

def discover(transport):
    return _obexftp.discover(transport)

def browsebt(addr, service):
    return _obexftp.browsebt(addr, service)
class client(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, transport):
        _obexftp.client_swiginit(self, _obexftp.new_client(transport))
    __swig_destroy__ = _obexftp.delete_client

    def callback(self, infocb):
        return _obexftp.client_callback(self, infocb)

    def discover(self):
        return _obexftp.client_discover(self)

    def connect(self, device, port, src=None):
        return _obexftp.client_connect(self, device, port, src)

    def connectpush(self, device, port, src=None):
        return _obexftp.client_connectpush(self, device, port, src)

    def connectsync(self, device, port, src=None):
        return _obexftp.client_connectsync(self, device, port, src)

    def disconnect(self):
        return _obexftp.client_disconnect(self)

    def chpath(self, name):
        return _obexftp.client_chpath(self, name)

    def mkpath(self, name):
        return _obexftp.client_mkpath(self, name)

    def cdup(self):
        return _obexftp.client_cdup(self)

    def cdtop(self):
        return _obexftp.client_cdtop(self)

    def get(self, path):
        return _obexftp.client_get(self, path)

    def list(self, path=None):
        return _obexftp.client_list(self, path)

    def get_capability(self, path=None):
        return _obexftp.client_get_capability(self, path)

    def get_file(self, path, localname):
        return _obexftp.client_get_file(self, path, localname)

    def put_file(self, filename, remotename=None):
        return _obexftp.client_put_file(self, filename, remotename)

    def put_data(self, data, remotename=None):
        return _obexftp.client_put_data(self, data, remotename)

    def delete(self, name):
        return _obexftp.client_delete(self, name)

# Register client in _obexftp:
_obexftp.client_swigregister(client)

